@@ -8,7 +8,7 @@ def create(args):
     legion = get_legion_var()
 
     # Get current repo values
-    repo = get_repo_var()
+    repo = get_repo_var()     
 
     print "Starting legion onto %s" % repo['heroku_name']
 
@@ -18,5 +18,5 @@ def create(args):
 
     # Config heroku
     print "Creating balancer server, name `%s`" % repo['heroku_name']
-    check_call(['heroku', 'apps:create', repo['heroku_name'],  '--buildpack', 'https://github.com/heroku/heroku-buildpack-nodejs#diet', '--remote', 'legion-balancer'], cwd=legion['tmp_server_path'])
+    check_call(['heroku', 'apps:create', repo['heroku_name'],  '--buildpack', 'https://github.com/heroku/heroku-buildpack-nodejs#diet', '--remote', 'legion-balancer'] + args, cwd=legion['tmp_server_path'])
     check_call(['git', 'push', 'legion-balancer', 'master'], cwd=legion['tmp_server_path'])
